pub enum TryLockError<T> {
Poisoned(PoisonError<T>),
LockedByCurrentThread,
WouldBlock,
}Expand description
An error that may be returned by ThreadCheckedMutex::try_lock.
Variants
Poisoned(PoisonError<T>)
Returned when a lock was acquired, but the lock was poisoned.
LockedByCurrentThread
Returned when a lock failed to be acquired because the thread attempting to acquire the lock was already holding the lock.
WouldBlock
Returned when a lock failed to be acquired because the lock was already held by a thread (other than the thread attempting to acquire the lock).
Implementations
Sourceimpl<T> TryLockError<T>
impl<T> TryLockError<T>
Sourcepub fn ignore_poison(self) -> PoisonlessTryLockResult<T>
pub fn ignore_poison(self) -> PoisonlessTryLockResult<T>
Silently converts any poison error into a successful result (see
PoisonError::into_inner), and otherwise returns the error unchanged in an Err.
Errors
If the provided error was not caused by poison, that error is returned.
Sourcepub fn panic_if_poison(self) -> TryLockError<Infallible>
pub fn panic_if_poison(self) -> TryLockError<Infallible>
Panics if the error was caused by poison, and otherwise returns the error unchanged.
Panics
Panics if the error was caused by poison.